import React, { useRef, useState, useEffect } from 'react';
import 'go-design-system-theme/lib/styles.css';
import 'go-design-system-icons';
import ContextMenu from 'go-design-system-context-menu';

//   {
//     name: 'digihealth',
//     disabled: true,
//   },
//   {
//     name: 'digihealth 1',
//     disabled: true,
//   },
//   {
//     name: 'digihealth 2',
//     disabled: true,
//   },
//   {
//     name: 'digihealth 3',
//     disabled: true,
//   },
//   {
//     name: 'Pan Forms',
//     icon: <Icon IconName="EarthFilled" iconProps={{size: 20}} />,
//     rightIcon: <Icon IconName="ChevronDown" iconProps={{size: 20}} />,
//   },
// ];

function BreadCrumbs(props) {
  const {
    items
  } = props;
  const ref = useRef();
  const [isMoreContextVisible, setIsMoreContextVisible] = useState(false);
  useEffect(() => {
    function handleClickOutside(event) {
      if (ref.current && !ref.current.contains(event.target)) {
        setIsMoreContextVisible(false);
      }
    }

    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, [ref]);

  const sanitizeBreadCrumbsToShow = () => {
    if (items.length < 4) {
      return items;
    } else {
      return [items[0], {
        name: '...',
        onClick: () => {
          setIsMoreContextVisible(!isMoreContextVisible);
        }
      }, items[items.length - 1]];
    }
  };

  const getOthersContextMenu = () => {
    if (items.length > 3) {
      const otherItems = [...items];
      otherItems.shift();
      otherItems.pop();
      return otherItems.map(item => {
        return {
          title: item.name,
          onClick: e => {
            setIsMoreContextVisible(false);

            if (item.onClick) {
              item.onClick(e);
            }
          }
        };
      });
    }
  };

  console.log('a');
  const sanitizedItems = sanitizeBreadCrumbsToShow();
  const othersContextMenu = getOthersContextMenu();

  const renderIcon = item => {
    if (!item.icon) return null;
    return /*#__PURE__*/React.createElement("div", {
      style: {
        marginRight: 6
      }
    }, item.icon);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "go-design-system-bread-crumbs"
  }, sanitizedItems.map((item, i) => {
    const className = item.disabled ? 'disabled' : '';
    return /*#__PURE__*/React.createElement("div", {
      key: `breadcrumb_${i}`,
      className: `item ${className}`,
      onClick: e => {
        if (item?.onClick) {
          item?.onClick(e);
        }
      }
    }, "\xA0 ", renderIcon(item), " ", item.name, " \xA0", sanitizedItems.length > i + 1 ? '/' : '', item.rightIcon ?? '');
  }), /*#__PURE__*/React.createElement(ContextMenu, {
    yPos: "40px",
    xPos: "30px",
    ref: ref,
    showMenu: isMoreContextVisible,
    items: [othersContextMenu]
  }));
}

export default BreadCrumbs;
